package com.yaohun.levelreward.config;

import com.yaohun.levelreward.LevelReward;
import com.yaohun.levelreward.data.RewardData;
import me.Demon.DemonPlugin.DemonAPI;
import me.Demon.DemonPlugin.data.GuiItemData;
import me.Demon.DemonPlugin.data.LangData;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.inventory.ItemStack;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * Config类用于管理配置数据，包括语言配置、界面物品数据和奖励设置
 */
public class Config {

    // 存储语言配置数据
    public static LangData langData;
    // 存储界面物品数据的映射表
    private static HashMap<String, GuiItemData> guiItemDataMap = new HashMap<>();
    // 存储奖励设置的列表
    private static List<RewardData> rewardDataList = new ArrayList<>();

    /**
     * 重新加载配置文件
     * 此方法应由LevelReward插件调用，以初始化或更新配置数据
     * @param plugin LevelReward插件实例，用于访问插件的配置文件
     */
    public static void reloadConfig(LevelReward plugin) {
        // 调用了DemonAPI中的LangData
        // 需要在AuLangs目录中创建一个 LevelReward.yml 文件存语言配置
        langData = DemonAPI.getLangData("LevelReward");
        // 重新加载和保存插件的配置文件
        plugin.reloadConfig();
        plugin.saveConfig();
        FileConfiguration config = plugin.getConfig();
        // 加载界面物品数据和奖励设置
        loadGuiItemData(config);
        loadRewardSettings(config);
    }

    /**
     * 从配置文件中加载奖励设置
     * 此方法清除现有的奖励数据列表，并从配置文件的"RewardSettings"部分重新加载
     * @param config 插件的配置文件
     */
    private static void loadRewardSettings(FileConfiguration config){
        // 清除现有的奖励数据列表
        rewardDataList.clear();
        // 获取"RewardSettings"配置部分
        ConfigurationSection section = config.getConfigurationSection("RewardSettings");
        // 如果该部分不存在，则直接返回
        if(section == null) {return;}
        // 遍历"RewardSettings"部分的所有键，并创建新的RewardData对象添加到列表中
        for (String rewardKey : section.getKeys(false)){
            rewardDataList.add(new RewardData(rewardKey,section));
        }
    }

    /**
     * 从配置文件中加载界面物品数据
     * 此方法清除现有的界面物品数据映射表，并从配置文件的"GuiItemData"部分重新加载
     * @param configuration 插件的配置文件
     */
    private static void loadGuiItemData(FileConfiguration configuration){
        // 清除现有的界面物品数据映射表
        guiItemDataMap.clear();
        // 获取"GuiItemData"配置部分
        ConfigurationSection section = configuration.getConfigurationSection("GuiItemData");
        // 如果该部分不存在，则直接返回
        if(section == null){return;}
        // 遍历"GuiItemData"部分的所有键，并创建新的GuiItemData对象添加到映射表中
        for (String itemKey : section.getKeys(false)){
            guiItemDataMap.put(itemKey,new GuiItemData(itemKey,section));
        }
    }

    /**
     * 根据物品键获取对应的ItemStack对象
     * 如果指定的物品键存在于映射表中，则返回对应的ItemStack对象的克隆；否则返回错误物品
     * @param itemKey 物品键
     * @return 对应的ItemStack对象的克隆或错误物品
     */
    public static ItemStack getItemStack(String itemKey) {
        // 检查物品键是否存在于映射表中
        if(guiItemDataMap.containsKey(itemKey)){
            // 返回对应的ItemStack对象的克隆
            return guiItemDataMap.get(itemKey).getItemStack().clone();
        }
        // 如果物品键不存在，则返回错误物品
        return DemonAPI.getErrItems();
    }

    /**
     * 获取奖励数据列表
     * @return 奖励数据列表
     */
    public static List<RewardData> getRewardDataList() {
        return rewardDataList;
    }

    /**
     * 根据奖励键获取对应的奖励数据
     * 如果找到匹配的奖励键，则返回对应的奖励数据；否则返回null
     * @param rewardKey 奖励键
     * @return 对应的奖励数据或null
     */
    public static RewardData getRewardData(String rewardKey) {
        // 遍历奖励数据列表
        for (RewardData rewardData : rewardDataList){
            // 如果找到匹配的奖励键，则返回对应的奖励数据
            if(rewardData.getRewardKey().equals(rewardKey)){
                return rewardData;
            }
        }
        // 如果没有找到匹配的奖励键，则返回null
        return null;
    }
}

