package com.yaohun.levelreward.data;

import org.bukkit.Bukkit;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.entity.Player;

import java.util.List;

/**
 * 奖励数据类，用于存储和管理奖励相关信息
 */
public class RewardData {

    // 奖励的唯一标识key
    private String rewardKey;

    // 奖励在GUI中的槽位位置
    private int slot;

    // 奖励图标的Base64编码（用于自定义头颅外观）
    private String base64;

    // 解锁奖励所需的最低等级
    private int needLevel;

    // 奖励物品列表（显示给玩家的奖励内容）
    private List<String> rewardList;

    // 领取奖励时需要执行的命令列表
    private List<String> commandList;

    /**
     * 构造函数，从配置中初始化奖励数据
     *
     * @param rewardKey 奖励的唯一key，用于在配置中查找对应数据
     * @param section 配置节点，包含该奖励的所有配置信息
     */
    public RewardData(String rewardKey, ConfigurationSection section){
        this.rewardKey = rewardKey;

        // 从配置中获取奖励所在的槽位
        this.slot = section.getInt(rewardKey+".slot");

        // 从配置中获取解锁奖励所需的等级
        this.needLevel = section.getInt(rewardKey+".level");

        // 从配置中获取Base64图标数据，默认为"default"
        this.base64 = section.getString(rewardKey+".base64","default");

        // 从配置中获取奖励物品列表
        this.rewardList = section.getStringList(rewardKey+".reward");

        // 从配置中获取需要执行的命令列表
        this.commandList = section.getStringList(rewardKey+".commands");
    }

    /**
     * 获取奖励的唯一标识key
     *
     * @return 奖励的key
     */
    public String getRewardKey() {
        return rewardKey;
    }

    /**
     * 获取奖励在GUI中的槽位
     *
     * @return 槽位索引
     */
    public int getSlot() {
        return slot;
    }

    /**
     * 获取奖励图标的Base64编码
     *
     * @return Base64字符串
     */
    public String getBase64() {
        return base64;
    }

    /**
     * 获取奖励物品列表
     *
     * @return 奖励描述文本列表
     */
    public List<String> getRewardList() {
        return rewardList;
    }

    /**
     * 获取解锁奖励所需等级
     *
     * @return 所需等级
     */
    public int getNeedLevel() {
        return needLevel;
    }

    /**
     * 执行奖励对应的命令
     * 如果是消息命令（以"msg:"开头），则向玩家发送消息；
     * 否则替换占位符后执行命令
     *
     * @param player 要执行命令的目标玩家
     */
    public void carryOutCommands(Player player){
        String playerName = player.getName();

        // 遍历所有命令并执行
        for(String command : commandList) {
            if (command.contains("msg:")) {
                // 如果是消息命令，去掉前缀后发送消息
                player.sendMessage(command.replace("msg:", "").replace("&", "§"));
                continue;
            }

            // 替换命令中的玩家名称占位符%p%为真实名称
            command = command.replace("%p%", playerName);

            // 执行命令
            player.performCommand(command);
        }

        // 记录日志
        Bukkit.getLogger().info("[等级奖励 - 发放] " + player.getName() + " 已执行奖励命令: " + rewardKey);
    }
}

