package com.yaohun.levelreward.gui;

import com.yaohun.aurechargedata.api.RechargeAPI;
import com.yaohun.aurechargedata.util.TimeType;
import com.yaohun.levelreward.LevelReward;
import com.yaohun.levelreward.config.Config;
import com.yaohun.levelreward.data.PlayerData;
import com.yaohun.levelreward.data.RewardData;
import com.yaohun.levelreward.hook.QuestStoryHook;
import com.yaohun.levelreward.manage.PlayerManager;
import com.yaohun.levelreward.util.MessageUtil;
import com.yaohun.levelreward.util.StackUtil;
import me.Demon.DemonLevelReward.Event.LevelRewardReceiveEvent;
import me.Demon.DemonPlugin.DemonAPI;
import me.Demon.DemonPlugin.Util.AreaType;
import me.Demon.DemonPlugin.data.NbtItem;
import org.bukkit.Bukkit;
import org.bukkit.Sound;
import org.bukkit.entity.Player;
import org.bukkit.event.Event;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.inventory.Inventory;
import org.bukkit.inventory.ItemStack;

import java.util.UUID;

/**
 * RewardGui类用于处理奖励界面的展示和玩家的点击事件
 * 它实现了Listener接口以监听玩家在GUI界面的点击行为
 */
public class RewardGui implements Listener{

    // 定义库存标题
    private static String invTitle = Config.langData.getMessage("invTitle");

    /**
     * 检查玩家是否在服务器首次登录超过60天
     *
     * @param player 要检查的玩家对象
     * @return 如果玩家首次登录超过60天返回true，否则返回false
     */
    public static boolean isTimeOut60Day(Player player){
        long firstPlayed = player.getFirstPlayed();
        if(firstPlayed == 0){
            return false;
        }
        long nowTime = System.currentTimeMillis();
        long days = (nowTime - firstPlayed) / (1000 * 60 * 60 * 24);
        if(days < 60){
            return false;
        }
        return true;
    }

    /**
     * 打开奖励界面
     *
     * 该方法负责创建并展示奖励界面，包括：
     * 1. 检查玩家是否满足时间条件
     * 2. 创建和填充界面库存
     * 3. 根据配置添加奖励物品
     *
     * @param player 要打开界面的玩家对象
     */
    public static void OpenGui(Player player) {
        // 获取玩家入服时间 并判断是否已超过60天
        if(isTimeOut60Day(player)){
            MessageUtil.sendMessage(player,"timeOutDay", Sound.ENTITY_BLAZE_DEATH);
            return;
        }
        Inventory inv = Bukkit.createInventory(null,27, invTitle);
        ItemStack glass = DemonAPI.glass(15, "§8#欢迎加入");
        if(DemonAPI.getAreaType() == AreaType.TaiWan){
            glass = DemonAPI.glass(15, "§8#歡迎加入");
        }
        int[] slot = {0, 8, 9, 17, 18, 26};
        for (int i : slot) {
            inv.setItem(i, glass);
        }
        for (RewardData rewardData : Config.getRewardDataList()){
            inv.setItem(rewardData.getSlot(), StackUtil.getGiftPack(player, rewardData));
        }
        player.openInventory(inv);
    }


    /**
     * 处理玩家在GUI界面中的点击事件
     *
     * 该事件处理器用于处理玩家在特定GUI(标题匹配invTitle)中的点击行为，
     * 主要实现以下功能：
     * 1. 验证点击的槽位和物品有效性
     * 2. 检查玩家是否满足领取奖励的条件
     * 3. 发放奖励并触发相关事件
     *
     * @param e InventoryClickEvent 库存点击事件对象，包含点击相关信息
     */
    @EventHandler
    private void onClick(InventoryClickEvent e) {
        int rawSlot = e.getRawSlot();
        Player player = (Player) e.getWhoClicked();
        String playerName = player.getName();

        // 只处理指定标题的GUI点击事件
        if(e.getView().getTitle().equalsIgnoreCase(invTitle)) {
            e.setCancelled(true);  // 取消所有点击事件的默认行为

            // 检查点击槽位是否在有效范围内(0-26)
            if(rawSlot < 0 || rawSlot > 26) {
                return;
            }

            // 验证被点击的物品是否有效
            ItemStack stack = e.getCurrentItem();
            if(stack == null || DemonAPI.itemIsNull(stack) || DemonAPI.itemIsLore(stack)) {
                return;
            }

            // 检查物品是否包含奖励标识
            NbtItem nbtItem = new NbtItem(stack);
            if(!nbtItem.hasKey("rewardKey")) {
                return;
            }

            // 获取奖励配置数据
            String rewardKey = nbtItem.getString("rewardKey");
            RewardData rewardData = Config.getRewardData(rewardKey);
            if(rewardData == null) {
                return;
            }

            // 检查玩家等级是否满足要求
            int needLevel = rewardData.getNeedLevel();
            if(player.getLevel() < needLevel) {
                MessageUtil.sendMessageKey(player, "noLevelRequest", Sound.ENTITY_VILLAGER_NO);
                return;
            }
            if(needLevel == 15){
                if(!QuestStoryHook.isCompleteQuest(player)){
                    player.closeInventory();
                    MessageUtil.sendMessageKey(player, "questStoryChecking", Sound.ENTITY_VILLAGER_NO);
                    return;
                }
            }
            if(rewardKey.contains("kejin")){
                int needRecharge = 1288;
                int recharge = RechargeAPI.getRechargeData(playerName, TimeType.ANNUAL);
                if (recharge < needRecharge) {
                    player.closeInventory();
                    String message = Config.langData.getMessage("inadequateRecharge");
                    message = message.replace("{coins}",String.valueOf((needRecharge - recharge)));
                    MessageUtil.sendMessage(player, message, Sound.ENTITY_VILLAGER_NO);
                    return;
                }
            }
            // 检查玩家是否已领取过该奖励
            PlayerManager playerManager = LevelReward.getPlayerManager();
            PlayerData playerData = playerManager.getPlayerData(playerName);
            if(playerData.isHasReward(rewardKey)) {
                MessageUtil.sendMessageKey(player, "alreadyReceived", Sound.ENTITY_VILLAGER_NO);
                return;
            }
            player.closeInventory();
            // 发放奖励并触发相关事件
            playerData.addReward(rewardKey);
            playerData.savePlayerData();
            rewardData.carryOutCommands(player);
            player.playSound(player.getLocation(), Sound.ENTITY_EXPERIENCE_ORB_PICKUP, 1.0f, 1.2f);

            LevelRewardReceiveEvent event = new LevelRewardReceiveEvent(player, rewardKey, needLevel);
            Bukkit.getPluginManager().callEvent(event);
        }
    }
}
